==> haskell-mono-traversable-instances-0.1.1.0-377.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-5glaXxQoDCIG0rWzyAekiW
key:                  mono-traversable-instances-0.1.1.0-5glaXxQoDCIG0rWzyAekiW
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  5af6f342dc720d584ea16e1016699654
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/mono-traversable-instances-0.1.1.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-5glaXxQoDCIG0rWzyAekiW
depends:
    base-4.18.2.1 comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot containers-0.6.7
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    dlist-instances-0.1.1.1-CJKDuS8fq9PBqGXaYa3dlm
    mono-traversable-1.0.21.0-9RUKUQu56O66rvR7vJ1jcU
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9 transformers-0.6.1.0
    vector-instances-3.4.3-D9XsKYeactIB5mBFijznBE

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-instances-0.1.1.0-378-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-DPzLlSr8fSJRRfnAVWKpz
key:                  mono-traversable-instances-0.1.1.0-DPzLlSr8fSJRRfnAVWKpz
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  f683fbcdc35b9e161eeeaa46bbfc3b7b
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/mono-traversable-instances-0.1.1.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-DPzLlSr8fSJRRfnAVWKpz
depends:
    base-4.18.2.1 comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL containers-0.6.7
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    dlist-instances-0.1.1.1-CJKDuS8fq9PBqGXaYa3dlm
    mono-traversable-1.0.21.0-DRPwtEa2I1e57PO0WNa046
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS transformers-0.6.1.0
    vector-instances-3.4.3-I7Qkh9V3qpNmvWkDy34LP

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
